import EventEmitter from "eventemitter3";
import { Graph, Node, Edge } from "@antv/graphlib";
import type { Layout, LayoutSupervisor } from "./types";
/**
 * The payload transferred from main thread to the worker.
 */
export interface Payload {
    layout: {
        id: string;
        options: any;
        iterations: number;
    };
    nodes: Node<any>[];
    edges: Edge<any>[];
}
export declare const SupervisorEvent: {
    /**
     * Get triggerred when each iteration finished.
     */
    LAYOUT_ITERATION: string;
    /**
     * Get triggerred when layout calculation is done.
     */
    LAYOUT_END: string;
};
interface SupervisorOptions {
    /**
     * Iterations run in algorithm such as d3force, will be passed in `tick()` later.
     */
    iterations: number;
}
/**
 * @example
 * const graph = new Graph();
 * const layout = new CircularLayout();
 *
 * const supervisor = new Supervisor(graph, layout, { auto: true });
 * supervisor.start();
 * supervisor.stop();
 * supervisor.kill();
 *
 * // lifecycle
 * supervisor.on('tick', () => {
 * });
 * supervisor.on('layoutend', () => {
 * });
 *
 * // Re-layout when graph changed.
 * graph.addNodes([{ id: 'node1' }, { id: 'node2' }]);
 *
 * // TODO: Custom layout.
 */
export declare class Supervisor extends EventEmitter implements LayoutSupervisor {
    private graph;
    private layout;
    private options?;
    /**
     * Internal worker.
     */
    private worker;
    /**
     * Flag of running state.
     */
    private running;
    constructor(graph: Graph<any, any>, layout: Layout<any>, options?: Partial<SupervisorOptions> | undefined);
    spawnWorker(): void;
    start(): this;
    stop(): this;
    kill(): void;
    isRunning(): boolean;
}
export {};
