import * as d3Force from "d3-force";
import { Graph, Node, LayoutMapping, OutNode, D3ForceLayoutOptions, Edge, LayoutWithIterations } from "../types";
/**
 * Layout the nodes' positions with d3's basic classic force
 *
 * @example
 * // Assign layout options when initialization.
 * const layout = new D3ForceLayout({ center: [100, 100] });
 * const positions = layout.execute(graph); // { nodes: [], edges: [] }
 *
 * // Or use different options later.
 * const layout = new D3ForceLayout({ center: [100, 100] });
 * const positions = layout.execute(graph, { center: [100, 100] }); // { nodes: [], edges: [] }
 *
 * // If you want to assign the positions directly to the nodes, use assign method.
 * layout.assign(graph, { center: [100, 100] });
 */
export declare class D3ForceLayout implements LayoutWithIterations<D3ForceLayoutOptions> {
    options: D3ForceLayoutOptions;
    id: string;
    private forceSimulation;
    private lastLayoutNodes;
    private lastLayoutEdges;
    private lastAssign;
    private lastGraph;
    private lastOptions;
    private running;
    constructor(options?: D3ForceLayoutOptions);
    /**
     * Return the positions of nodes and edges(if needed).
     */
    execute(graph: Graph, options?: D3ForceLayoutOptions): LayoutMapping;
    /**
     * To directly assign the positions to the nodes.
     */
    assign(graph: Graph, options?: D3ForceLayoutOptions): void;
    /**
     * Stop simulation immediately.
     */
    stop(): void;
    restart(): void;
    /**
     * Manually steps the simulation by the specified number of iterations.
     * When finished it will trigger `onLayoutEnd` callback.
     * @see https://github.com/d3/d3-force#simulation_tick
     */
    tick(iterations?: number): {
        nodes: OutNode[];
        edges: Edge[];
    };
    private genericForceLayout;
    /**
     * Prevent overlappings.
     * @param {object} simulation force simulation of d3
     */
    overlapProcess(simulation: d3Force.Simulation<any, any>, options: {
        nodeSize: number | number[] | ((d?: Node) => number) | undefined;
        nodeSpacing: number | number[] | ((d?: Node) => number) | undefined;
        collideStrength: number;
    }): void;
}
