import type { Graph, GridLayoutOptions, LayoutMapping, Layout } from "./types";
/**
 * Layout arranging the nodes in a grid.
 *
 * @example
 * // Assign layout options when initialization.
 * const layout = new GridLayout({ rows: 10 });
 * const positions = layout.execute(graph); // { nodes: [], edges: [] }
 *
 * // Or use different options later.
 * const layout = new GridLayout({ rows: 10 });
 * const positions = layout.execute(graph, { rows: 20 }); // { nodes: [], edges: [] }
 *
 * // If you want to assign the positions directly to the nodes, use assign method.
 * layout.assign(graph, { rows: 20 });
 */
export declare class GridLayout implements Layout<GridLayoutOptions> {
    options: GridLayoutOptions;
    id: string;
    constructor(options?: GridLayoutOptions);
    /**
     * Return the positions of nodes and edges(if needed).
     */
    execute(graph: Graph, options?: GridLayoutOptions): LayoutMapping;
    /**
     * To directly assign the positions to the nodes.
     */
    assign(graph: Graph, options?: GridLayoutOptions): void;
    private genericGridLayout;
}
