import type { Graph, LayoutMapping, RadialLayoutOptions, Layout } from "../types";
/**
 * Layout arranging the nodes' on a radial shape
 *
 * @example
 * // Assign layout options when initialization.
 * const layout = new RadialLayout({ focusNode: 'node0' });
 * const positions = layout.execute(graph); // { nodes: [], edges: [] }
 *
 * // Or use different options later.
 * const layout = new RadialLayout({ focusNode: 'node0' });
 * const positions = layout.execute(graph, { focusNode: 'node0' }); // { nodes: [], edges: [] }
 *
 * // If you want to assign the positions directly to the nodes, use assign method.
 * layout.assign(graph, { focusNode: 'node0' });
 */
export declare class RadialLayout implements Layout<RadialLayoutOptions> {
    options: RadialLayoutOptions;
    id: string;
    constructor(options?: RadialLayoutOptions);
    /**
     * Return the positions of nodes and edges(if needed).
     */
    execute(graph: Graph, options?: RadialLayoutOptions): LayoutMapping;
    /**
     * To directly assign the positions to the nodes.
     */
    assign(graph: Graph, options?: RadialLayoutOptions): void;
    private genericRadialLayout;
    private run;
    private oneIteration;
}
