import type { Graph, LayoutMapping, RandomLayoutOptions, Layout } from "./types";
/**
 * Layout randomizing the nodes' position
 *
 * @example
 * // Assign layout options when initialization.
 * const layout = new RandomLayout({ center: [100, 100] });
 * const positions = layout.execute(graph); // { nodes: [], edges: [] }
 *
 * // Or use different options later.
 * const layout = new RandomLayout({ center: [100, 100] });
 * const positions = layout.execute(graph, { center: [100, 100] }); // { nodes: [], edges: [] }
 *
 * // If you want to assign the positions directly to the nodes, use assign method.
 * layout.assign(graph, { center: [100, 100] });
 */
export declare class RandomLayout implements Layout<RandomLayoutOptions> {
    options: RandomLayoutOptions;
    id: string;
    constructor(options?: RandomLayoutOptions);
    /**
     * Return the positions of nodes and edges(if needed).
     */
    execute(graph: Graph, options?: RandomLayoutOptions): LayoutMapping;
    /**
     * To directly assign the positions to the nodes.
     */
    assign(graph: Graph, options?: RandomLayoutOptions): void;
    private genericRandomLayout;
}
