import type { Matrix, Edge, Node, OutNode, Degree, Point } from "../types";
export declare const floydWarshall: (adjMatrix: Matrix[]) => Matrix[];
export declare const getAdjMatrix: (data: {
    nodes: Node[];
    edges: Edge[];
}, directed: boolean) => Matrix[];
/**
 * scale matrix
 * @param matrix [ [], [], [] ]
 * @param ratio
 */
export declare const scaleMatrix: (matrix: Matrix[], ratio: number) => Matrix[];
/**
 * depth first traverse, from leaves to root, children in inverse order
 * if the fn returns false, terminate the traverse
 */
export declare const traverseTreeUp: <T extends {
    children?: T[] | undefined;
}>(data: T, fn: (param: T) => boolean) => void;
/**
 * calculate the bounding box for the nodes according to their x, y, and size
 * @param nodes nodes in the layout
 * @returns
 */
export declare const getLayoutBBox: (nodes: OutNode[]) => {
    minX: number;
    minY: number;
    maxX: number;
    maxY: number;
};
/**
 * 获取节点集合的平均位置信息
 * @param nodes 节点集合
 * @returns 平局内置
 */
export declare const getAvgNodePosition: (nodes: OutNode[]) => {
    x: number;
    y: number;
};
export declare const getCoreNodeAndRelativeLeafNodes: (type: "leaf" | "all", node: Node, edges: Edge[], nodeClusterBy: string, degreesMap: {
    [id: string]: Degree;
}, nodeMap: {
    [id: string]: Node;
}) => {
    coreNode: Node;
    relativeLeafNodes: Node[];
    sameTypeLeafNodes: Node[];
};
/**
 * calculate the euclidean distance form p1 to p2
 * @param p1
 * @param p2
 * @returns
 */
export declare const getEuclideanDistance: (p1: Point, p2: Point) => number;
